<template>
    <div class="module-cart-summary">Presupuesto de Compra</div>
    <div id="accordionCartSummary" class="accordion accordion-cart-summary">
        <div class="accordion-item">
            <h2 id="headingOne" class="accordion-header">
                <button
                    class="accordion-button"
                    type="button"
                    data-bs-toggle="collapse"
                    data-bs-target="#collapseOne"
                    aria-expanded="true"
                    aria-controls="collapseOne"
                >
                    <span class="title-accordion">
                        Cantidad de Productos <span class="total-product">({{ totalProducts }})</span>
                    </span>
                    <div class="title-price-accordion">{{ formatCurrency(subtotal) }}</div>
                </button>
            </h2>
            <div
                id="collapseOne"
                class="accordion-collapse collapse show"
                aria-labelledby="headingOne"
                data-bs-parent="#accordionCartSummary"
            >
                <div class="accordion-body">
                    <ProductCount />
                </div>
            </div>
        </div>
        <div class="accordion-item">
            <h2 id="headingTwo" class="accordion-header">
                <button
                    class="accordion-button collapsed"
                    type="button"
                    data-bs-toggle="collapse"
                    data-bs-target="#collapseTwo"
                    aria-expanded="false"
                    aria-controls="collapseTwo"
                >
                    <span class="title-accordion">Método de Envío</span>
                    <div class="title-price-accordion">{{ formatCurrencyShipping(shippingCost) }}</div>
                </button>
            </h2>
            <div
                id="collapseTwo"
                class="accordion-collapse collapse"
                aria-labelledby="headingTwo"
                data-bs-parent="#accordionCartSummary"
            >
                <div class="accordion-body">
                    <ShippingMethod :show-address-form="false" @validate="setFormValidity" />
                </div>
            </div>
        </div>
        <div class="accordion-item">
            <h2 id="headingThree" class="accordion-header">
                <button
                    class="accordion-button collapsed"
                    type="button"
                    data-bs-toggle="collapse"
                    data-bs-target="#collapseThree"
                    aria-expanded="false"
                    aria-controls="collapseThree"
                >
                    <span class="title-accordion">Modo de Pago</span>
                    <div class="title-price-accordion">{{ formatCurrencyPayment(paymentDiscount) }}</div>
                </button>
            </h2>
            <div
                id="collapseThree"
                class="accordion-collapse collapse"
                aria-labelledby="headingThree"
                data-bs-parent="#accordionCartSummary"
            >
                <div class="accordion-body">
                    <PaymentMethod />
                </div>
            </div>
        </div>
    </div>
    <!--    <DiscountCupon />-->
    <TotalsCart />

    <button class="just-button total-button" :disabled="!isConfirmButtonEnabled" @click="$emit('confirm')">
        Confirmar Compra
    </button>
</template>

<script setup>
import { ref, watch } from "vue";
import { computed } from "vue";
import { cartStore } from "../../../js/stores/cart.js";

import ProductCount from "./ProductCount.vue";
import ShippingMethod from "./ShippingMethod.vue";
import PaymentMethod from "./PaymentMethod.vue";
import DiscountCupon from "./DiscountCupon.vue";
import TotalsCart from "./../TotalsCart.vue";

const emit = defineEmits(["confirm"]);

const isFormValid = ref(false);

const setFormValidity = (validity) => {
    isFormValid.value = validity;
};

const store = cartStore();

const totalProducts = computed(() => store.itemCount);
const subtotal = computed(() => store.subtotal);
const shippingCost = computed(() => store.getShippingCost());
const paymentDiscount = computed(() => store.getPaymentDiscount());

const isConfirmButtonEnabled = computed(() => isFormValid.value && totalProducts.value > 0);

watch(shippingCost, () => store.getShippingCost());
watch(paymentDiscount, () => store.getPaymentDiscount());

const formatCurrency = (value) => {
    return new Intl.NumberFormat("es-AR", {
        style: "currency",
        currency: "ARS",
        minimumFractionDigits: 2,
        maximumFractionDigits: 2,
    }).format(value);
};

const formatCurrencyShipping = (value) => {
    if (value === 0) {
        return "Gratis";
    }
    return new Intl.NumberFormat("es-AR", {
        style: "currency",
        currency: "ARS",
        minimumFractionDigits: 2,
        maximumFractionDigits: 2,
    }).format(value);
};

const formatCurrencyPayment = (value) => {
    if (value === 0) {
        return "";
    }
    return (
        "-" +
        new Intl.NumberFormat("es-AR", {
            style: "currency",
            currency: "ARS",
            minimumFractionDigits: 2,
            maximumFractionDigits: 2,
        }).format(value)
    );
};
</script>

<style lang="scss">
@use "../../../scss/variables" as vars;

.module-cart-summary {
    text-transform: uppercase;
    font-family: "Plus Jakarta Sans", sans-serif;
    font-weight: 800;
    border-bottom: 2px vars.$gris-just solid;
    padding-bottom: 20px;
}

.accordion-cart-summary {
    .accordion-button::after {
        transition: none;
        float: left;
        margin: 0;
        position: absolute;
        background-color: black;
        color: white !important;
        border-radius: 3px;
        background-image: url("data:image/svg+xml,%3Csvg xmlns='http://www.w3.org/2000/svg' viewBox='0 0 16 16' fill='%23ffffff'%3E%3Cpath fill-rule='evenodd' d='M1.646 4.646a.5.5 0 0 1 .708 0L8 10.293l5.646-5.647a.5.5 0 0 1 .708.708l-6 6a.5.5 0 0 1-.708 0l-6-6a.5.5 0 0 1 0-.708z'/%3E%3C/svg%3E") !important;
    }

    .accordion-button {
        --bs-accordion-btn-focus-box-shadow: none;

        position: relative;
        display: flex;
        align-items: center;
        justify-content: space-between;
        width: 100%;
        padding: 1.25rem 0;
    }

    .accordion-item {
        background-color: transparent;

        --bs-accordion-btn-bg: transparent;

        border: transparent;
        border-bottom: 2px vars.$gris-just solid;
    }

    .title-accordion {
        margin-left: 30px;
        font-family: "Plus Jakarta Sans", sans-serif;
        font-size: 15px;
        font-weight: 700;
        color: vars.$negro-just;
    }

    .total-product {
        color: vars.$late-just;
    }

    .accordion-header {
        --bs-accordion-active-bg: transparent;
    }

    .accordion-button:not(.collapsed) {
        box-shadow: none;
    }

    .title-price-accordion {
        font-family: "Plus Jakarta Sans", sans-serif;
        color: vars.$negro-just;
        font-size: 15px;
        font-weight: 700;
    }
}
</style>
